% script for 3d plots of transfer function magnitudes
% |H(z)| = |z^2 - 1.5 z + 1| / |z^2 - 1.5 z + 0.8|
%
% G. Doblinger, TU-Wien, 03-2001

echo off
[x,y] = meshgrid(-1:0.025:1, -1:0.025:1);
z = x + j * y;
b = [1 -1.5 1];
a = [1 -1.5 0.8];
H = abs(polyval(b,z)) ./ abs(polyval(a,z));
i1 = find(H > 4);
H(i1) = 4;

close all
pos = [0.01 0.2 0.6 0.7];
hfig = figure('name','Z Domain','Units','normal','Position',pos);
colordef(hfig,'black');
colormap('jet');
surf(x,y,H,'FaceColor','interp','EdgeColor','none','FaceLighting','phong');
axis tight
camlight right
view([55,30]);
grid on
xlabel('Re\{z\}');
ylabel('Im\{z\}');
zlabel('|H(z)|');
axis vis3d
for n = 55:15:415
   view([n,30]);
   drawnow
end
axis normal
   
