function y = blockstate_filt(b,a,x,M)
%function y = blockstate_filt(b,a,x,M)
%
% discrete-time block state-space filtering for scalar inputs
% (using optimum block length)
%
% a,b   numerator and denominator of transfer function
% x     input signal vector 
% M     optional block length (optimum is used, if omitted)
% y     output signal vector
%
% G. Doblinger, 12-2000, TU-Wien

if nargin == 0
   help blockstate_filt
   return
end
Ns = max(length(a),length(b))-1;
disp(sprintf('filter order = %d',Ns));
Mopt = round(sqrt(2)*Ns);
disp(sprintf('Optimum block length = %d',Mopt));
if nargin == 3
   M = Mopt;
end
Nops = round(Ns^2/M + 2*Ns + 0.5*(M+1));
disp(sprintf('Operations per sampling interval = %d',Nops));

s = zeros(Ns,1);
Nx = length(x);
Nx1 = M * ceil(Nx/M);        
x = [x(:) ; zeros(Nx1-Nx,1)];  % append zeros to make signal length
                               % a multiple of M
[A,B,C,D] = tf2blockss(b,a,M);
y = zeros(size(x));
flops(0);
for n = 1:M:Nx1
   nb = n:n+M-1;
   y(nb) = C*s + D*x(nb); 
   s = A*s + B*x(nb);
end
y = y(1:Nx);
