function hi = deconvolve(h,Nhi)
% function hi = deconvolve(h,Nhi)
%
% devonvolution using LS-solution: (h * hi)(n) = delta(n)
%
% h     given impulse response
% Nhi   given length of invers impulse resonse
%       (Nhi = Nh, if omitted)
% hi    impulse response of inverse filter 
%
% (c) 2000, G. Doblinger TU-Wien

if nargin == 0
   help deconvolve
   return
elseif nargin == 1
   Nh = length(h);
   Nhi = Nh;
else
   Nh = length(h);
end

Ny = Nh + Nhi - 1;
y = [1 ; zeros(Ny-1,1)];

% compute convolution matrix H

h1 = [zeros(Nhi-1,1) ; h(:) ; zeros(Nhi-1,1)];
ic = [0:Ny-1]';
ir = Nhi:-1:1;
H = ic(:,ones(Nhi,1)) + ir(ones(Ny,1),:);
H(:) = h1(H);

% find inverse filter by solving LS-problem

%Hi = inv(H.'*H)*H.';
%hi = Hi(:,1);

hi = H \ y;

% plot result

close all
if strcmp(upper(computer),'PCWIN')
   pos1 = [0.5 0.51 0.49 0.405];
   axfnt = 9;
   ticfnt = 8;
   yoff = 0.49;
else	
   pos1 = [0.5 0.6 0.49 0.38];
   axfnt = 13;
   ticfnt = 12;
   yoff = 0.51;
end
fsig = figure('numbertitle','off','name','Time domain',...
   'Units','normal','Position',pos1);
colordef(fsig,'black');

t = 0:Nh-1;
if Nh <= 100
   str_plot = 'discret';

else
   str_plot =  'plot';
end
subplot(2,1,1), eval([str_plot,'(t,h)']);
h1 = xlabel('Time index');
h2 = ylabel('Given filter');
h3 = title('Impulse responses');
set(h1,'fontsize',axfnt);
set(h2,'fontsize',axfnt);
set(h3,'fontsize',axfnt);
set(gca,'fontsize',ticfnt);
t = 0:Nhi-1;
if Nhi <= 100
   str_plot = 'discret';

else
   str_plot =  'plot';
end
subplot(2,1,2), eval([str_plot,'(t,hi)']);
h2 = ylabel('Inverse filter');
set(h2,'fontsize',axfnt);
set(gca,'fontsize',ticfnt);

pos1(1) = pos1(1) - 0.495;

fmag = figure('numbertitle','off','name',...
   'Frequency domain: DFT magnitude (x-zoom an)',...
   'Units','normal','Position',pos1);
colordef(fmag,'black');

Nf = max([1024,Nh,Nhi]);
Nfh = floor(Nf/2) + 1;
H = fft(h(:),Nf);
H = H(1:Nfh);
Hi = fft(hi(:),Nf);
Hi = Hi(1:Nfh);
Hges = H .* Hi;
phiges = angle(Hges);
H = abs(H);
Hi = abs(Hi);
Hmag = 20*log10(H+eps);
Himag = 20*log10(Hi+eps);
Hgesmag = 20*log10(abs(Hges)+eps);

f = [linspace(0,1,Nfh)]';
subplot(2,1,1), plot(f,H,'y',f,Hi,'m'), grid on;
h1 = xlabel('Frequency normalized to Fs/2');
h2 = ylabel('Magnitude');
h3 = title('Given filter (y), and inverse filter (m)');
set(h1,'fontsize',axfnt);
set(h2,'fontsize',axfnt);
set(h3,'fontsize',axfnt);
set(gca,'fontsize',ticfnt);
subplot(2,1,2), plot(f,Hmag,'y',f,Himag,'m'), grid on;
h2 = ylabel('Magnitude in dB');
set(h2,'fontsize',axfnt);
set(gca,'fontsize',ticfnt);
zoom(fmag,'xon');

pos1(2) = pos1(2) - yoff;
fmag1 = figure('numbertitle','off','name',...
   'Frequency domain: DFT magnitude (x-zoom an)',...
   'Units','normal','Position',pos1);
colordef(fmag1,'black');

subplot(2,1,1), plot(f,Hgesmag,'y'), grid on;
h1 = xlabel('Frequency normalized to Fs/2');
h2 = ylabel('Magnitude in dB');
h3 = title('Overall filter response');
set(h1,'fontsize',axfnt);
set(h2,'fontsize',axfnt);
set(h3,'fontsize',axfnt);
set(gca,'fontsize',ticfnt);
subplot(2,1,2), plot(f,phiges,'y'), grid on;
h2 = ylabel('Phase in rad');
set(h2,'fontsize',axfnt);
set(gca,'fontsize',ticfnt);
zoom(fmag1,'xon');
