function filefilt(b,a,infile,outfile)
%function filefilt(b,a,infile,outfile)
%
% filter signal stored as 16 bit (short) data in binary file
% (see also MATLAB function filter)
%
% b     numerator coefficients of filter transfer function
% a     denominator coefficients of filter transfer function
% in/outfile  binary data file names in quotes
%
% G. Doblinger, TU-Wien, 11-2000

if nargin == 0
   help filefilt
   return
end
if ~isstr(infile) 
   error('input file name must be a string (use quotes)');
elseif ~isstr(outfile)
   error('output file name must be a string (use quotes)');
end

N = max(length(a),length(b))-1;  % N = filter order
state = zeros(N,1);            
fin = fopen(infile,'rb');
fout = fopen(outfile,'wb');
Nb = 2^14;                       % Nb = block size
Nx = Nb;
while (Nx == Nb)
   [x,Nx] = fread(fin,Nb,'short');
   [y,state] = filter(b,a,x,state);
   fwrite(fout,y,'short');
end
fclose(fin); 
fclose(fout); 