function X = dec_fft(x,L)
%function X = dec_fft(x,L)
%
% FFT with number of frequency points L smaller than number of time points N
%
% G. Doblinger, 12-2000, TU-Wien

if nargin == 0
   help dec_fft
   return
end

x = x(:);
Nx = length(x);
if L > Nx
   error('L must be less than N (length of x)');
end
M = ceil(Nx/L);
N = M*L;                   % N is a multiple of L
x = [x ; zeros(N-Nx,1)];   % append zeros, if necessary
Xb = zeros(L,M);           % matrix for storage of M signal blocks of length L  
Xb(:) = x;                 % columns of Xb are subsequent signal
                           % blocks of length L
xb = sum(Xb.');            % compute row sums of Xb
X = fft(xb);               % decimated FFT of length L

% plot results to compare FFTs

close all
if strcmp(upper(computer),'PCWIN')
   pos1 = [0.5 0.4 0.49 0.5];
else	
   pos1 = [0.5 0.6 0.49 0.4];
end

fmag = figure('numbertitle','off','name','DFT magnitude I (x-zoom an)',...
   'Units','normal','Position',pos1);
colordef(fmag,'black');

Nh = floor(N/2)+1;
Lh = floor(L/2)+1;
Xt = fft(x);
Xmag = 20*log10(abs(Xt(1:Nh))+eps);
f = linspace(0,1,Nh);
Xmagd = 20*log10(abs(X(1:Lh))+eps);
fd = linspace(0,1,Lh);
plot(f,Xmag,'r',fd,Xmagd,'c');
xlabel('Frequency normalized to Fs/2');
ylabel('Magnitude in dB');
title(sprintf('%d point FFT and %d point decimated FFT (cyan)', N, L));
grid on;
zoom(fmag,'xon');

pos1(1) = pos1(1) - 0.495;  % position of next figure
fmag1 = figure('numbertitle','off','name','DFT magnitude II (x-zoom an)',...
   'Units','normal','Position',pos1);
colordef(fmag1,'black');

% show effect of interpolation on decimated FFT

X = fft(xb,N);              % pad length L signal with N-L zeros
Xmagd = 20*log10(abs(X(1:Nh))+eps);
plot(f,Xmag,'r',f,Xmagd,'c');
xlabel('Frequency normalized to Fs/2');
ylabel('Magnitude in dB');
title(sprintf('%d point FFT and interpolation of decimated FFT (cyan)', N));
grid on;
zoom(fmag,'xon');



