function [zd,pd,kd] = bilzt(z,p,k,fc)
% function [zd,pd,kd] = bilzt(z,p,k,fc)
%
% bilinear transform of analog low pass (prototype filter) transfer function
% into digital domain
%
% z,zd   vector of zeros
% p,pd   vector of poles
% k,kd   gain factor
% fc     low pass cut-off frequency normalized to Fs/2
%
% G. Doblinger, TU-Wien, 8-1994

if nargin == 0
   help bilzt
   return
end

np = length(p);
nz = length(z);   
v = tan(pi*fc/2);

if isempty(z)           % no numerator polynom in transfer function
   kd = k * v^np / real(prod(1 - v * p));
   if np == 1
      zd = -1;
   else   
      zd = -1 * ones(size(p));
   end   
   pd = (1 + v * p ) ./ (1 - v * p);
elseif np == nz
   kd = k * real(prod(1 - v * z)) / real(prod(1 - v * p));
   zd = (1 + v * z ) ./ (1 - v * z);
   pd = (1 + v * p ) ./ (1 - v * p);
elseif np == nz + 1     % there is a zero at infinity in s-plane
   kd = v * k * real(prod(1 - v * z)) / real(prod(1 - v * p));
   zd = (1 + v * z ) ./ (1 - v * z);
   [r,c] = size(zd);
   if r == 1
      zd = [-1 zd];     % include zero at -1 in z-plane
   else
      zd = [-1 ; zd];
   end      
   pd = (1 + v * p ) ./ (1 - v * p);        
else
   error('BILZT: Wrong number of poles and zeros');
end          
