function h = firkw(fc,fr,ar)
% function  h = firkw(fc,fr,ar)
%
% purpose: Kaiser window design of linear-phase FIR lowpass filter
% call:    h = firkw(fc,fr,ar)
%
% fc  passband edge frequeny normalized to Fs/2
% fr  stopband edge frequeny normalized to Fs/2
% ar  stopband attenuation in dB
%
% G. Doblinger, TU-Wien, 08-1994

if nargin == 0
   help firkw
   return
end
if max(fc,fr) > 1
   error('FIRKW: frequency must be normalized to Fs/2');
elseif fc > fr
   error('FIRKW: passband edge > stopband edge');
end

% compute Kaiser window parameter beta
   
if ar < 21
   beta = 0;
elseif ar < 50
   beta = 0.5842*(ar-21)^0.4 + 0.07886*(ar-21);
else
   beta = 0.1102*(ar-8.7);
end

% estimate filter length

N = 1 + fix((ar-7.95)/(7.18*(fr-fc)));

% compute impulse response

N2 = floor(N/2);
n = [1:N2]';
fc = fc + 0.5*(fr-fc);  % modify passband edge, otherwise fc is 3dB cutoff frequency
if rem(N,2) == 0
   n = pi*(n-0.5);
   h = sin(fc*n)./n;
   h = [h(N2:-1:1) ; h];
else
   n = pi*n;
   h = sin(fc*n)./n;
   h = [h(N2:-1:1) ; fc ; h];
end
h = h .* kaiser(N,beta);    
