function h = firlso(N,f,m)
% function h = firlso(N,f,m)
%
% purpose: least squares design of linear phase FIR filters (impulse response
%          with odd symmetry) 
% call: h = firlso(N,f,m)
%
% N   filter length (length of impulse response)
% f   vector of frequency points at which magnitude is specified,
%     frequency is normalized to Fs/2, thus all components of f must be in [0,1]  
% m   vector of magnitude of frequency response at given frequency points
%     (each component corresponds to the respective component of f)
% h   impulse response vector
%
% G. Doblinger, TU-Wien, 07-1994

if nargin == 0
   help firlso
   return
end
   
if length(f) ~= length(m)
   error('FIRLSO: vectors f and m must be of same length');
end

if rem(N,2) == 0
   M = N/2;
   C = 2*sin(pi*f(:)*(M - 0.5 - [0:M-1]));     % system matrix
   h = C \ m(:);                               % solve LS-problem
   h = [h ; -h(M:-1:1)];                       % append anti-symmetric part
else
   M = (N-1)/2;
   C = 2*sin(pi*f(:)*(M - [0:M-1]));      
   h = C \ m(:);
   h = [h ; 0 ; -h(M:-1:1)];
end


