function barkplot(M,Lb,Fs)
% function barkplot(M,Lb,Fs)
%
% plot critical bandwidths (bark scale) and nonuniform filter bank partition
%
% M   vector of subsampling factors
% Lb  vector of frequency scale partition (same length as M)
% Fs  sampling frequency in Hz
%
% G. Doblinger, TU-Wien, 06-1996

if nargin == 0
   help barkplot
   return
end

Nm = length(M);
if Nm ~= length(Lb)
   error('vectors M, Lb must have same length')
end
M = M(:).';
Lb = Lb(:).';

% empirical critical bandwidth law

fcb = logspace(1,5,100);
Fsh = Fs/2;
ii = find(fcb < Fsh);
fcb = [fcb(1:max(ii)) Fsh];   % limit to half the sampling frequency
cbv = 25 + 75*(1+1.4*(fcb/1000).^2).^0.69; 

% frequency scale vector of filter bank

cbf = Fsh ./ M;
cbf = [cbf ; cbf];
cbf = cbf(:);
fcf = Fsh * cumsum(Lb./M);
fcf = [fcf ; fcf];
fcf = [10 ; fcf(:)];
fcf = fcf(1:length(fcf)-1);

% create partition string for title

sLb = [];
for k=1:Nm
   sLb = [sLb [' ',int2str(Lb(k)),'/',int2str(M(k))]];
end

% plot results

close all
if strcmp(upper(computer),'PCWIN')
   pos = [0.5 0.5 0.49 0.415];
   axfnt = 8;
   ticfnt = 7;
else	
   pos = [0.5 0.6 0.49 0.4];
   axfnt = 12;
   ticfnt = 10;
end
ff = figure('name','Critical Bands und Filterbank Approximation','Units','normal','Position',pos);
figurebackcolor = 'black';
colordef(ff,figurebackcolor);

loglog(fcb,cbv,'y--',fcf,cbf,'r'), grid on,
gh = title(['N = ', int2str(sum(Lb)),', Partitionierung = ',sLb]); set(gh,'fontsize',axfnt);
set(gca,'GridLineStyle',':','Xcolor',[0,0.7,0.2],'Ycolor',[0,0.7,0.2]);
gh = xlabel('Center frequency in Hz'); set(gh,'fontsize',axfnt);
gh = ylabel('Band width in Hz'); set(gh,'fontsize',axfnt);
set(gca,'fontsize',ticfnt);
set(gca,'PlotBoxAspectRatio',[1.8 1 1]);

