function y = fft_fib(N,L,x)
%function y = fft_fib(N,L,x)
%
% analysis/synthesis FFT flterbank using STFT
%
% N      window length = FFT length
% L      oversampling faktor (L = 4, typically)
% x      input signal vector
% y      output signal vector
%
% G. Doblinger, TU-Wien, 1-2001

M = round(N/L);             % decimation factor
if M < 1
   error('L must be less than N');
end

% create time window function

a = 0.54;
b = -0.46;
h = 2*sqrt(M/N)/(sqrt(4*a^2+2*b^2))*(a + b*cos(pi/N*(2*[0:N-1]'+1)));

Nf = N;                     % FFT length
Nx = length(x);
x = x(:);
y = zeros(Nx,1);
for m = 1:M:Nx-N+1
   % analysis filter bank

   m1 = m:m+N-1; 
   X = fft(x(m1).*h,Nf);    % cut out a block of length N,
                            % apply weighting function, and FFT

   % synthesis filter bank

   y1 = real(ifft(X,Nf));   % perform inverse FFT 
                            % real() avoids tiny imaginary parts

   % overlap-add of successive IFFT outputs

   y(m1) = y(m1) + h.*y1(1:N);
end