function [y_lp,y_hp] = latafib2(x,alpha)
%function [y_lp,y_hp] = latafib2(x,alpha)
%
% 2-channel critically sampled lattice analysis filter bank
%
% x            input signal vector
% alpha        vector of lattice coefficients created with QMF_Lat_Coef()
%              or qmf_2hb()
% y_lp, y_hp   output signal vectors of low pass and high pass filters
%
% G. Doblinger, TU-Wien, 6-1998

Nx = length(x);

% compute lattice input signals p0, q0

p0 = x(:)/sqrt(prod(1+alpha.^2));     % apply gain factor
q0 = [0 ; p0(1:Nx-1)];                % delay q-signal
p0 = p0(2:2:Nx);                      % down-sampling at input
q0 = q0(2:2:Nx);
Nq = length(q0)-1;

% compute lattice stages output signals

p = p0 - alpha(1)*q0;
q = q0 + alpha(1)*p0;
for n = 2:length(alpha)
   q = [0 ; q(1:Nq)];
   pt = p;
   p = p - alpha(n)*q;
   q = q + alpha(n)*pt;
end
y_lp = p;
y_hp = q;
