function y = latsfib2(y_lp,y_hp,alpha)
%function y = latsfib2(y_lp,y_hp,alpha)
%
% 2-channel critically sampled lattice synthesis filter bank
%
% y_lp, y_hp   input signal vectors
% alpha        vector of lattice coefficients
% y            output signal vector
%
% G. Doblinger, TU-Wien, 6-1998

Nx = length(y_lp);
Nq = Nx - 1;
alpha = alpha(end:-1:1);     % use reversed coefficients

% compute first stage output signals

y_lp = y_lp(:);
y_hp = y_hp(:);
p = y_lp + alpha(1)*y_hp;
q = y_hp - alpha(1)*y_lp;

for n = 2:length(alpha)      % loop of remaining stages
   p = [0 ; p(1:Nq)];        % delayed p-vector
   pt = p;
   p = p + alpha(n)*q;
   q = q - alpha(n)*pt;
end

% up-sampling at output

Nx = 2*Nx;
p_int = zeros(Nx,1);
p_int(2:2:Nx) = p;
q_int = zeros(Nx,1);
q_int(2:2:Nx) = q;
p_int = [0 ; p_int(1:Nx-1)];
y = (p_int + q_int)/sqrt(prod(1+alpha.^2));
