function [E,dE] = nuf_err_grad(ht,Lf,Lt,A,Ut1,Ut2,Utp,Q,alpha)
%
% error and gradient function for nuftrans.m, optimization with fminunc()
% (for MATLAB version 6.x)
% see nuftrans.m for parameters
%
% G. Doblinger, TU-Wien, 05-1996

fi = Lf:-1:1;
I = ones(1,Lt);
d = Ut1*ht;
D = d*I;
di = d(fi);
b1 = d.*di;
b3 = d.^2;
db1 = Ut1.*(di*I) + Ut1(fi,:).*D;
db3 = 2*Ut1.*D;
d = Ut2*ht;
D = d*I;
di = d(fi);
b2 = d.*di;
b4 = d.^2;
db2 = Ut2.*(di*I) + Ut2(fi,:).*D;
db4 = 2*Ut2.*D;
d = Utp*ht;
b5 = d.^2;
db5 = 2*Utp.*(d*I);
bs = Q*ht;

E = alpha(1)*norm(A(:,1)-b1)^2 + alpha(2)*norm(A(:,2)-b2)^2 + alpha(3)*norm(A(:,3)-b3)^2 + ...
    alpha(4)*norm(A(:,4)-b4)^2 + alpha(5)*norm(A(:,5)-b5)^2 + alpha(6)*(ht'*bs);
dE = alpha(1)*(b1-A(:,1))'*db1 + alpha(2)*(b2-A(:,2))'*db2 +...
     alpha(3)*(b3-A(:,3))'*db3 + alpha(4)*(b4-A(:,4))'*db4 +...
     alpha(5)*(b5-A(:,5))'*db5 + alpha(6)*bs';
dE = 2*dE; 