function play(x,Fs,Nbits)
% function play(x,Fs,Nbits)
%
% purpose:  play matrix x as audio signal via sound-board on Linux-PC
%           (1 column for mono, and 2 columns for stereo signals)
% call:     play(x) or play(x,Fs) or play(x,Fs,Nbits)
%
% arguments: x       floating point vector in [-1,1)
%            Fs      sampling frequency in Hz (default 8000 Hz)  
%            Nbits   number of conversion bits (8 or 16), default 16 Bits
%
% copyright (c), G. Doblinger, TU Wien, EMAIL: gdobling@email.tuwien.ac.at

% created: 12.2.99

% other functions required: play (SOX front end)

% check arguments

if nargin == 0
   help play
   return
elseif nargin == 1
   Fs = 8000;
   Nbits = 16;
elseif nargin == 2
   Nbits = 16;
end

if Nbits ~= 8 & Nbits ~= 16
   error('Nbits must be 8 or 16');
end

[nr,nc] = size(x);
if nr <= 2 & nc <= 2
  return
elseif nr == 2
  x = x.';
end
  
xmax = max(max(abs(x)));
if xmax >1
   disp('INFO: vector not in amplitude range [-1,1)')
   disp('      (data will be automatically scaled)')
   x = x / xmax;
end

wavwrite(x,Fs,Nbits,'/tmp/playtmp.wav');
unix('play /tmp/playtmp.wav &');
