function  sigplot(p1,p2,p3,p4,p5,p6,p7,p8) 
% function sigplot(n1,x1,n2,x2,n3,x3,n4,x4)
%
% call: sigplot(x), sigplot(n1,x1), sigplot(x1,x2), sigplot(n1,x1,n2,x2),
%       sigplot(x1,x2,x3), ...
%
% time domain plot of up to 4 real-valued, or 2 complex-valued
% discrete-time signals in one figure window
% (signal vectors may have different lengths)
%
% n1 ... n4       starting time indices (default is 0)
%                 (can be either omitted for each signal, or must be
%                 present for each signal) 
% x, x1 ... x4    signal vectors
%
% copyright (c) G.Doblinger TU-Wien, 12-92, 9-93

% mod.:  Db, 6-93    adapted for MATLAB 4.0
%            9-93    new axis labeling

na = nargin;
if na == 0
   help sigplot
   return
end

if length(p1) == 1                  % first argument is time index
   if rem(na,2) ~= 0
      error('SIGPLOT: check type (or number) of arguments');
   end
   nflag = 1;
   na = na/2;
   Nx = zeros(1,na);                % hold signal lengths
   im = zeros(1,na);                % hold flag for imagaginary detect
   for k = 1:na
      kk = int2str(k);
      eval(['n',kk,'=p',int2str(2*k-1),';']);
      eval(['x',kk,'=p',int2str(2*k),';']);
      eval(['Nx(k)=length(x',kk,');']);
      eval(['im(k)=any(imag(x',kk,'));']);
   end
else
   nflag = 0;
   Nx = zeros(1,na);
   im = zeros(1,na);
   for k = 1:na
      kk = int2str(k);
      eval(['n',kk,'=0;']);
      eval(['x',kk,'=p',kk,';']);
      eval(['Nx(k)=length(x',kk,');']);
      eval(['im(k)=any(imag(x',kk,'));']);
   end
end

if any(find(Nx == 0))
   error('SIGPLOT: signal must not be empty');      
elseif any(find(Nx == 1))
   error('SIGPLOT: signal must be vectors of length greater 1');      
elseif na > 4
   error('SIGPLOT: maximal 4 signals allowed');
elseif sum(im) >= 1 & na > 2
   error('SIGPLOT: maximal 1 complex and 1 real signal allowed');
elseif sum(im) > 2
   error('SIGPLOT: maximal 2 complex signals allowed');
end      

% loop to plot signals

close all
figurebackcolor = 'black';
pos1 = [0.5 0.6 0.49 0.38];
fsig = figure('numbertitle','off','name','Signal plot in time domain',...
   'Units','normal','Position',pos1);
colordef(fsig,figurebackcolor);

for k = 1:na
   kk = int2str(k);
   str_x = 'n';
   if nflag  == 1
      str_y = inputname(2*k);
      if strcmp(str_y,'')
	 str_y = 'x(n)';
      end
   else
      str_y = inputname(k);
      if strcmp(str_y,'')
	 str_y = ['x',int2str(k),'(n)'];	
      end
   end
   if Nx(k) <= 150, str_plot = 'discret';        % create plot string
   else,            str_plot = 'plot';    end
   eval(['n=n',kk,':Nx(k)+n',kk,'-1;']);         % vector of time indices
   dn = ceil(abs(max(n) - min(n))/80);           % use for offset of x-axis
   if im(k)
      eval(['subplot(2',int2str(min(na,2)),int2str(2*k-1),');']);
      eval([str_plot,'(n,real(x',kk,'))']);
      xlabel(str_x);
      ylabel(['Re{',str_y,'}']);
      if strcmp(str_plot,'discret')
         xax = axis;
         xax(1) = xax(1) - dn;
         xax(2) = xax(2) + dn;
         axis(xax);
      end   
      set(gca,'fontsize',12);
      eval(['subplot(2',int2str(min(na,2)),int2str(2*k),');']);
      eval([str_plot,'(n,imag(x',kk,'))']);
      xlabel(str_x);
      ylabel(['Im{',str_y,'}']);
      if strcmp(str_plot,'discret')
         xax = axis;
         xax(1) = xax(1) - dn;
         xax(2) = xax(2) + dn;
         axis(xax);
      end   
      set(gca,'fontsize',12);
   else
      if na == 3 & k == 3
         h=subplot(212);
      elseif na > 1
         eval(['subplot(',int2str(min(na,2)),int2str(1+(na>2)),kk,');']);
      end
      eval([str_plot,'(n,x',kk,')']);
      xlabel(str_x);
      ylabel(str_y);
      if strcmp(str_plot,'discret')
         xax = axis;
         xax(1) = xax(1) - dn;
         xax(2) = xax(2) + dn;
         axis(xax);
      end   
      set(gca,'fontsize',12);
   end
end            




